@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 # docs/COPYING 2a + DRY: https://github.com/getmail6/getmail6
 # Please refer to the git history regarding who changed what and when in this file.
 
@@ -21,6 +22,17 @@ Currently implemented:
   MultidropIMAPSSLRetriever
 '''
 
+import os
+import poplib
+import imaplib
+import types
+
+from getmailcore.exceptions import *
+from getmailcore.constants import *
+from getmailcore.utilities import *
+from getmailcore.baseclasses import *
+from getmailcore._retrieverbases import *
+
 __all__ = [
     'SimplePOP3Retriever',
     'SimplePOP3SSLRetriever',
@@ -35,17 +47,6 @@ __all__ = [
     'MultidropIMAPSSLRetriever',
 ]
 
-import os
-import poplib
-import imaplib
-import types
-
-from getmailcore.exceptions import *
-from getmailcore.constants import *
-from getmailcore.utilities import *
-from getmailcore.baseclasses import *
-from getmailcore._retrieverbases import *
-
 
 #
 # Functional classes
@@ -391,6 +392,9 @@ class SimpleIMAPRetriever(IMAPRetrieverBase, IMAPinitMixIn):
         ConfBool(name='use_cram_md5', required=False, default=False),
         ConfBool(name='use_kerberos', required=False, default=False),
         ConfBool(name='use_xoauth2', required=False, default=False),
+        ConfString(name='imap_search', required=False, default=None),
+        ConfString(name='imap_on_delete', required=False, default=None),
+        ConfBool(name='imap_id_extension', required=False, default=False),
     )
     received_from = None
     received_with = 'IMAP4'
@@ -417,8 +421,6 @@ class SimpleIMAPSSLRetriever(IMAPRetrieverBase, IMAPSSLinitMixIn):
         ConfInstance(name='configparser', required=False),
         ConfDirectory(name='getmaildir', required=False, default='~/.getmail/'),
 
-        # socket.ssl() and socket timeouts were incompatible in Python 2.3;
-        # if you have problems, comment this line out
         ConfInt(name='timeout', required=False, default=180),
         ConfString(name='server'),
         ConfInt(name='port', required=False, default=imaplib.IMAP4_SSL_PORT),
@@ -442,6 +444,9 @@ class SimpleIMAPSSLRetriever(IMAPRetrieverBase, IMAPSSLinitMixIn):
         ConfBool(name='use_kerberos', required=False, default=False),
         ConfBool(name='use_xoauth2', required=False, default=False),
         ConfString(name='ssl_cert_hostname', required=False, default=None),
+        ConfString(name='imap_search', required=False, default=None),
+        ConfString(name='imap_on_delete', required=False, default=None),
+        ConfBool(name='imap_id_extension', required=False, default=False),
     )
     received_from = None
     received_with = 'IMAP4-SSL'
@@ -485,6 +490,9 @@ class MultidropIMAPRetriever(MultidropIMAPRetrieverBase, IMAPinitMixIn):
         ConfBool(name='use_kerberos', required=False, default=False),
         ConfBool(name='use_xoauth2', required=False, default=False),
         ConfString(name='envelope_recipient'),
+        ConfString(name='imap_search', required=False, default=None),
+        ConfString(name='imap_on_delete', required=False, default=None),
+        ConfBool(name='imap_id_extension', required=False, default=False),
     )
     received_from = None
     received_with = 'IMAP4'
@@ -511,8 +519,6 @@ class MultidropIMAPSSLRetriever(MultidropIMAPRetrieverBase, IMAPSSLinitMixIn):
         ConfInstance(name='configparser', required=False),
         ConfDirectory(name='getmaildir', required=False, default='~/.getmail/'),
 
-        # socket.ssl() and socket timeouts were incompatible in Python 2.3;
-        # if you have problems, comment this line out
         ConfInt(name='timeout', required=False, default=180),
         ConfString(name='server'),
         ConfInt(name='port', required=False, default=imaplib.IMAP4_SSL_PORT),
@@ -537,6 +543,9 @@ class MultidropIMAPSSLRetriever(MultidropIMAPRetrieverBase, IMAPSSLinitMixIn):
         ConfBool(name='use_xoauth2', required=False, default=False),
         ConfString(name='envelope_recipient'),
         ConfString(name='ssl_cert_hostname', required=False, default=None),
+        ConfString(name='imap_search', required=False, default=None),
+        ConfString(name='imap_on_delete', required=False, default=None),
+        ConfBool(name='imap_id_extension', required=False, default=False),
     )
     received_from = None
     received_with = 'IMAP4-SSL'
